package com.enbinari.laplanaaldiatv;

import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.support.v17.leanback.widget.ArrayObjectAdapter;
import android.support.v17.leanback.widget.HeaderItem;
import android.support.v17.leanback.widget.ImageCardView;
import android.support.v17.leanback.widget.ListRow;
import android.support.v17.leanback.widget.ListRowPresenter;
import android.support.v17.leanback.widget.ObjectAdapter;
import android.support.v17.leanback.widget.OnItemViewClickedListener;
import android.support.v17.leanback.widget.Presenter;
import android.support.v17.leanback.widget.Row;
import android.support.v17.leanback.widget.RowPresenter;
import android.support.v4.app.ActivityOptionsCompat;
import android.text.TextUtils;

import java.util.Locale;

public class BusquedaFragment
        extends android.support.v17.leanback.app.SearchFragment implements
        android.support.v17.leanback.app.SearchFragment.SearchResultProvider {
    private static final int NUM_ROWS = 3;
    private static final int SEARCH_DELAY_MS = 1000;
    private ArrayObjectAdapter mRowsAdapter;
    private Handler mHandler = new Handler();
    private String mQuery;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        mRowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());
        setTitle("Introduce la búsqueda...");
        setSearchResultProvider(this);
        setOnItemViewClickedListener(new ItemViewClickedListener());
    }

    @Override
    public ObjectAdapter getResultsAdapter() {
        return mRowsAdapter;
    }

    @Override
    public boolean onQueryTextChange(String newQuery) {
        mRowsAdapter.clear();
        loadQuery(newQuery);
        return true;
    }

    @Override
    public boolean onQueryTextSubmit(String query) {
        mRowsAdapter.clear();
        loadQuery(query);
        return true;
    }

    private void loadQuery(String query) {
        mQuery = query;
        mHandler.removeCallbacks(mDelayedLoad);
        if (!TextUtils.isEmpty(query) && !query.equals("nil")) {
            mHandler.postDelayed(mDelayedLoad, SEARCH_DELAY_MS);
        }
    }

    private void loadRows() {
        Integer i = 0;
        ArrayObjectAdapter listRowAdapter = new ArrayObjectAdapter(
                new CardPresenter());
        for (Movie movie : MovieList.list) {
            if (movie.getTitle().toLowerCase(Locale.ENGLISH)
                    .contains(mQuery.toLowerCase(Locale.ENGLISH))
                    || movie.getDescription().toLowerCase(Locale.ENGLISH)
                    .contains(mQuery.toLowerCase(Locale.ENGLISH))) {
                i = i + 1;
                listRowAdapter.add(movie);
            }
        }
        HeaderItem header = new HeaderItem(0, mQuery + " encontrados " + i);
        mRowsAdapter.add(new ListRow(header, listRowAdapter));
    }

    private Runnable mDelayedLoad = new Runnable() {
        @Override
        public void run() {
            loadRows();
        }
    };

    private final class ItemViewClickedListener
            implements OnItemViewClickedListener {
        @Override
        public void onItemClicked(Presenter.ViewHolder itemViewHolder,
                                  Object item, RowPresenter.ViewHolder rowViewHolder, Row row) {
            Intent intent = new Intent(getActivity(), ActividadDetalles
                    .class);
            intent.putExtra(ActividadDetalles.MOVIE, (Movie) item);
            Bundle bundle = ActivityOptionsCompat
                    .makeSceneTransitionAnimation(getActivity(),
                            ((ImageCardView) itemViewHolder.view).getMainImageView(),
                            ActividadDetalles.SHARED_ELEMENT_NAME).toBundle();
            getActivity().startActivity(intent, bundle);
        }
    }
}