package com.enbinari.laplanaaldiatv;

import android.app.FragmentManager;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.os.AsyncTask;
import android.os.Bundle;
import android.support.v17.leanback.app.BrowseFragment;
import android.support.v17.leanback.widget.ArrayObjectAdapter;
import android.support.v17.leanback.widget.HeaderItem;
import android.support.v17.leanback.widget.ImageCardView;
import android.support.v17.leanback.widget.ListRow;
import android.support.v17.leanback.widget.ListRowPresenter;
import android.support.v17.leanback.widget.OnItemViewClickedListener;
import android.support.v17.leanback.widget.Presenter;
import android.support.v17.leanback.widget.Row;
import android.support.v17.leanback.widget.RowPresenter;
import android.support.v4.app.ActivityOptionsCompat;
import android.util.Log;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

import org.json.JSONArray;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.lang.reflect.Type;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;


public class FragmentPrincipal extends BrowseFragment implements DialogClickListener{

    private static final int GRID_ITEM_WIDTH = 200;
    private static final int GRID_ITEM_HEIGHT = 200;

    private Object selectedItem;
    private Presenter.ViewHolder mViewHolder;

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);
        leerDatos();

    }

    private void setupEventListeners() {
        setOnItemViewClickedListener(new ItemViewClickedListener());
        setOnSearchClickedListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getActivity(), SearchActivity.class);
                startActivity(intent);
            }
        });
    }
   private void leerDatos() {
       MovieList.list = new ArrayList<Movie>();
       new ImportVideos().execute();
    }


    private void iniciarInterfazUsuario() {
        setTitle("La Plana al Día TV");
        setHeadersState(HEADERS_ENABLED);
        setHeadersTransitionOnBackEnabled(true);
        setBrandColor(getResources().getColor(R.color.fastlane_background));
        setSearchAffordanceColor(getResources().getColor(R.color.search_opaque));
    }

    private void cargarListas() {
        ArrayObjectAdapter rowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());

        CardPresenter cardPresenter = new CardPresenter();
        List<String> categories = getCategories();
        if (categories == null || categories.isEmpty()) return;
        for (String category : categories) {
            ArrayObjectAdapter listRowAdapter = new ArrayObjectAdapter(cardPresenter);
            for (Movie movie : MovieList.list) {
                if (category.equalsIgnoreCase(movie.getCategory()))
                    listRowAdapter.add(movie);
            }
            if (listRowAdapter.size() > 0) {
                HeaderItem header = new HeaderItem(rowsAdapter.size() - 1, category);
                rowsAdapter.add(new ListRow(header, listRowAdapter));
            }
        }
        listaPreferencias(rowsAdapter);

        setAdapter(rowsAdapter);
    }

    private List<String> getCategories() {
        if (MovieList.list == null)
            return null;
        List<String> categories = new ArrayList<String>();
        for (Movie movie : MovieList.list) {
            if (!categories.contains(movie.getCategory())) {
                categories.add(movie.getCategory());
            }
        }
        return categories;
    }

    private void listaPreferencias(ArrayObjectAdapter adapter) {
        HeaderItem gridHeader = new HeaderItem(adapter.size() - 1, "PREFERENCIAS");
        GridItemPresenter mGridPresenter = new GridItemPresenter();
        ArrayObjectAdapter gridRowAdapter = new ArrayObjectAdapter(mGridPresenter);
        //gridRowAdapter.add("Vistas");
        //gridRowAdapter.add("Errores");
        //gridRowAdapter.add("Preferencias");
        gridRowAdapter.add("Protección");
        adapter.add(new ListRow(gridHeader, gridRowAdapter));
    }



    private class GridItemPresenter extends Presenter {
        @Override
        public ViewHolder onCreateViewHolder(ViewGroup parent) {
            TextView view = new TextView(parent.getContext());
            view.setLayoutParams(new ViewGroup.LayoutParams(GRID_ITEM_WIDTH, GRID_ITEM_HEIGHT));
            view.setFocusable(true);
            view.setFocusableInTouchMode(true);
            view.setBackgroundColor(getResources().getColor(R.color.default_background));
            view.setTextColor(Color.WHITE);
            view.setGravity(Gravity.CENTER);
            return new ViewHolder(view);
        }

        @Override
        public void onBindViewHolder(ViewHolder viewHolder, Object item) {
            ((TextView) viewHolder.view).setText((String) item);
        }

        @Override
        public void onUnbindViewHolder(ViewHolder viewHolder) {
        }
    }


    @Override
    public void onPasswordEntered(String password) {
        if (selectedItem instanceof Movie){
            SharedPreferences sharedPreferences = getActivity().getSharedPreferences("prefs", Context.MODE_PRIVATE);
            if (sharedPreferences.getString("password", "").equals(password)) {
                Movie movie = (Movie) selectedItem;
                Intent intent = new Intent(getActivity(), ActividadDetalles.class);
                intent.putExtra(ActividadDetalles.MOVIE, movie);
                Bundle bundle = ActivityOptionsCompat.makeSceneTransitionAnimation(getActivity(), ((ImageCardView) mViewHolder.view).getMainImageView(), ActividadDetalles.SHARED_ELEMENT_NAME).toBundle();
                getActivity().startActivity(intent, bundle);
            }else{
                Toast.makeText(getActivity(), "Contraseña incorrecta", Toast.LENGTH_LONG).show();
            }
        }else {
            SharedPreferences sharedPreferences = getActivity().getSharedPreferences("prefs", Context.MODE_PRIVATE);
            SharedPreferences.Editor editor = sharedPreferences.edit();
            editor.putString("password", password);
            editor.commit();
            Toast.makeText(getActivity(), "Contraseña establecida.", Toast.LENGTH_LONG).show();
        }
    }

    @Override
    public void onPasswordEmpty() {
      if (selectedItem instanceof String){
            SharedPreferences sharedPreferences = getActivity().getSharedPreferences("prefs", Context.MODE_PRIVATE);
            SharedPreferences.Editor editor = sharedPreferences.edit();
            if (sharedPreferences.getString("password", "") != "") {
                editor.remove("password");
                editor.commit();
                Toast.makeText(getActivity(), "Contraseña deshabilitada.", Toast.LENGTH_LONG).show();
            }
        }
    }

    private final class ItemViewClickedListener implements OnItemViewClickedListener {


        @Override
        public void onItemClicked(Presenter.ViewHolder itemViewHolder, Object item, RowPresenter.ViewHolder rowViewHolder, Row row) {
            selectedItem = item;
            mViewHolder = itemViewHolder;

            // PELÍCULA
            if (item instanceof Movie) {
                SharedPreferences sharedPreferences = getActivity().getSharedPreferences("prefs", Context.MODE_PRIVATE);
                if (sharedPreferences.getString("password", "") != "") { // Hay una contraseña guardada
                    FragmentManager fm = getFragmentManager();
                    ProteccionDialogFragment dialog = new ProteccionDialogFragment();
                    dialog.setTargetFragment(FragmentPrincipal.this, 0);
                    dialog.setTitle("Este contenido está protegido. Introduce la contraseña para poder visualizarlo.");
                    dialog.show(fm, "dialog");
                }
                else {
                    Movie movie = (Movie) item;
                    Intent intent = new Intent(getActivity(), ActividadDetalles.class);
                    intent.putExtra(ActividadDetalles.MOVIE, movie);
                    Bundle bundle = ActivityOptionsCompat.makeSceneTransitionAnimation(getActivity(), ((ImageCardView) itemViewHolder.view).getMainImageView(), ActividadDetalles.SHARED_ELEMENT_NAME).toBundle();
                    getActivity().startActivity(intent, bundle);
                }
            }



            // PROTECCIÓN
            else if (item instanceof String) {
                if (item.equals("Protección")){
                    ProteccionDialogFragment dialog = new ProteccionDialogFragment();
                    dialog.setTargetFragment(FragmentPrincipal.this, 0);
                    dialog.setTitle("¿Quieres proteger el contenido con contraseña?");
                    dialog.show(getFragmentManager(), "dialog");
                }
                Toast.makeText(getActivity(), ((String) item),  Toast.LENGTH_SHORT).show();
            }
        }


    }
    public class ImportVideos extends AsyncTask<Void, Void, String> {
        String response = "";

        public void onPreExecute() {
            super.onPreExecute();
        }

        @Override
        protected String doInBackground(Void... arg0) {
            String json ="";
            HttpURLConnection conexion = null;
            try {
                URL url = new URL("http://enbinari.com/neobar/movies.json");

                conexion = (HttpURLConnection) url.openConnection();

                if (conexion.getResponseCode() == HttpURLConnection.HTTP_OK) {
                    BufferedReader reader = new BufferedReader(new InputStreamReader(conexion.getInputStream()));
                    String line;
                    while ((line = reader.readLine()) != null) {
                        Log.d("json_line",json);
                        json = json + line;
                    }
                    reader.close();
                    conexion.disconnect();
                } else {
                    Log.e("LaPlanaAlDia_TV", conexion.getResponseMessage());
                    conexion.disconnect();
                }
            } catch (Exception e) {
                Log.e("LaPlanaAlDia_TV", e.getMessage(), e);
                conexion.disconnect();
            }
            response=json;
            return response;

        }

        public void onPostExecute(String res) {
            try {
                String json = response;

                if (json != null) {
                    Gson gson = new Gson();
                    Type collection = new TypeToken<ArrayList<Movie>>() {}.getType();
                    MovieList.list = gson.fromJson(json, collection);
                }
            } catch (Exception e) {
                Log.e("LaPlanaAlDia_TV", e.getMessage(), e);
            }
            iniciarInterfazUsuario();
            cargarListas();
            setupEventListeners();
        }
    }



}


